function [U,FreeDofs] = assemDir_1D(Coordinates,DNodes,FHandle,varargin)
% ASSEMDIR_1D Dirichlet boundary conditions.
%
%   [U,L,FREEDOFS] = ASSEMDIR_1D(COORDINATES,DNODES,FHANDLE)
%   incoporates the Dirichlet boundary conditions with the data given by
%   FHANDLE at the vertices denoted by DNODES into the right-hand side load
%   vector L and the finite element solution U.
%
%   FREEDOFS is a matrix specifying the vertices with no prescribed
%   Dirichlet boundary data.  
%
%   [U,FREEDOFS] = ASSEMDIR_1D(COORDINATES,DNODES,FHANDLE,FPARAM)
%   also handles the variable length argument list FPARAM to the boundary
%   data function FHANDLE.
%
%   Example:
%
%   Coordinates = transpose(0:.01:1);
%   GD_Handle = @(x,varargin)zeros(size(x));
%   DNodes = [1 size(Coordinates,1)];
%   [U,L,FreeDofs] = assemDir_1D(Coordiantes,DHandle,GD_Handle);

%   Copyright 2007 Christoph Winter
%   SAM - Seminar for Applied Mathematics
%   ETH-Zentrum
%   CH-8092 Zurich, Switzerland

  % Intialize constants

  nCoordinates = size(Coordinates,1);
  
  % Compute set of free dofs 
 
  FreeDofs = setdiff(1:nCoordinates,DNodes);
  
  % Incorporate Dirichlet boundary condition
  
  U = zeros(nCoordinates,1);
 
  U(DNodes(1)) = FHandle(Coordinates(DNodes(1)),varargin{:});
  if(length(DNodes) > 1)
    U(DNodes(2)) = FHandle(Coordinates(DNodes(2)),varargin{:});    
  end 
  
return